@@ -26,6 +26,7 @@ File-related utilities
 
 
 import codecs
+import errno
 import glob
 import locale
 import os
@@ -214,6 +215,13 @@ def delete(path, shred = False):
             delpath = wipe_name(path)
         try:
             os.rmdir(delpath)
+        except OSError, e:
+            # [Errno 39] Directory not empty
+            # https://bugs.launchpad.net/bleachbit/+bug/1012930
+            if errno.ENOTEMPTY == e.errno:
+                print "info: directory '%s' is not empty" % (path)
+            else:
+                raise
         except WindowsError, e:
             # WindowsError: [Error 145] The directory is not empty:
             # 'C:\\Documents and Settings\\username\\Local Settings\\Temp\\NAILogs'
@@ -238,7 +246,7 @@ def delete(path, shred = False):
         else:
             os.remove(path)
     else:
-        raise Exception("Unsupported special file type: '%s'" % path)
+        print "info: unsupported special file type: '%s'" % (path)
 
 
 def ego_owner(filename):
@@ -422,7 +430,7 @@ def wipe_contents(path, truncate = True):
     try:
         f = open(path, 'wb')
     except IOError, e:
-        if 13 == e.errno: # permission denied
+        if e.errno == errno.EACCES: # permission denied
             os.chmod(path, 0200) # user write only
             f = open(path, 'wb')
         else:
@@ -486,8 +494,8 @@ def wipe_path(pathname, idle = False ):
                 f = tempfile.TemporaryFile(dir = pathname, suffix = __random_string(maxlen))
                 break
             except OSError, e:
-                if e.errno == 36:
-                    # OSError: [Errno 36] File name too long
+                if e.errno == errno.ENAMETOOLONG:
+                    # OSError: [Errno ENAMETOOLONG] File name too long
                     if maxlen > 10:
                         maxlen -= 10
                     i += 1
@@ -528,7 +536,7 @@ def wipe_path(pathname, idle = False ):
         except OSError, e:
             # Linux gives errno 24
             # Windows gives errno 28 No space left on device
-            if e.errno in (24, 28):
+            if e.errno in (errno.EMFILE, errno.ENOSPC):
                 break
             else:
                 raise
@@ -544,14 +552,14 @@ def wipe_path(pathname, idle = False ):
                     yield estimate_completion()
                     last_idle = time.time()
         except IOError, e:
-            if 28 != e.errno:
+            if e.errno != errno.ENOSPC:
                 raise
         # individual characters
         try:
             while True:
                 f.write(chr(0))
         except IOError, e:
-            if 28 != e.errno:
+            if e.errno != errno.ENOSPC:
                 raise
         try:
             f.flush()
